# Optional Configurations

The following is a list of optional values you can specify in the *settings.yml* file.

| Setting             | Default | Description                                                  |
| :------------------ | :------ | :----------------------------------------------------------- |
| records_per_request | 200     | Number of records returned in a single page request.         |
| aws_access_key      | *None*  | AWS Access Key for Key-based authentication to AWS services. |
| aws_secret_key      | *None*  | AWS Secret Key for Key-based authentication to AWS services. | 
| aws_profile_name    | *None*  | Name for Profile-based authentication to AWS services.       |
| aws_region_name     | *None*  | AWS Region Name                                              |
| rate_limit          | *None*  | Record return rate limits (see **Rate Limits** section below) |
| cdns                | *None*  | CDNs used to customize location client libraries             |

## Example

``` yaml
settings:
  records_per_request: 200
  aws_region_name: us-east-1
```

## Rate Limits

As an enhanced security feature it is possible to limit the maximum number of rows returned over a period of time.  To set these values use the *settings* section as follows:

``` yaml
settings:
  rate_limit:
    records: 20000
    period: 10 # minutes
```

The example above will limit the maximum rows that can be downloaded to 20,000 records in any 10 minute timeframe.  This limit is regardless of the number of queries executed.

## CDNs

The CDNs used to pull the client libraries are configurable, but by default will pull from the public CDNs.  Examples of configuration is shown below with the default values for each.  To change just include in the settings file and modify as desired.  Any attributes other than the required *url* will be placed in the html as name=value pairs.

``` yaml
settings:
  cdns:
    fontawesome:
      url: https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css
      integrity: sha512-DTOQO9RWCH3ppGqcWaEA1BIZOC6xxalwEsw9c2QQeAIftl+Vegovlnee1c9QX4TctnWMn13TZye+giMm8e2LwA==
      crossorigin: anonymous
      referrerpolicy: no-referrer
    jquery:
      url: https://ajax.googleapis.com/ajax/libs/jquery/3.7.1/jquery.min.js
```